@@ -23,6 +23,10 @@
 # Imports
 ###############################################################################
 
+from __future__ import unicode_literals
+from builtins import str
+from builtins import object
+
 import importlib
 import logging
 import os
